package com.ruoyi.buyerapi.mapper;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerVoucherProject;

/**
 * 辅助帐凭证项目关系Mapper接口
 *
 * @author ruoyi
 * @date 2022-09-22
 */
public interface BuyerVoucherProjectMapper
{
    /**
     * 查询辅助帐凭证项目关系
     *
     * @param id 辅助帐凭证项目关系主键
     * @return 辅助帐凭证项目关系
     */
    public BuyerVoucherProject selectBuyerVoucherProjectById(Long id);

    /**
     * 查询辅助帐凭证项目关系列表
     *
     * @param buyerVoucherProject 辅助帐凭证项目关系
     * @return 辅助帐凭证项目关系集合
     */
    public List<BuyerVoucherProject> selectBuyerVoucherProjectList(BuyerVoucherProject buyerVoucherProject);

    /**
     * 新增辅助帐凭证项目关系
     *
     * @param buyerVoucherProject 辅助帐凭证项目关系
     * @return 结果
     */
    public int insertBuyerVoucherProject(BuyerVoucherProject buyerVoucherProject);

    /**
     * 修改辅助帐凭证项目关系
     *
     * @param buyerVoucherProject 辅助帐凭证项目关系
     * @return 结果
     */
    public int updateBuyerVoucherProject(BuyerVoucherProject buyerVoucherProject);

    /**
     * 删除辅助帐凭证项目关系
     *
     * @param id 辅助帐凭证项目关系主键
     * @return 结果
     */
    public int deleteBuyerVoucherProjectById(Long id);

    public int deleteBuyerVoucherProject(BuyerVoucherProject buyerVoucherProject);

    /**
     * 批量删除辅助帐凭证项目关系
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBuyerVoucherProjectByIds(Long[] ids);
}
